#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import numpy as np
from ase.io import read, write
import matplotlib.pyplot as plt
from mpl_toolkits.axes_grid1 import make_axes_locatable

############################################################
# number of points in x/y direction
nx = ny  = 10

if not os.path.isfile('pes_xy.npy'):
    pes = np.zeros((nx-1, ny-1))
    for ii in range(nx-1):
        for jj in range(ny-1):
            pes[ii, jj] = read('{:02d}-{:02d}/OUTCAR'.format(ii, jj)).get_potential_energy()
    np.save('pes_xy.npy', pes)

pes = np.load('pes_xy.npy')
# PBC
pes = np.pad(pes, (0, 1), 'wrap')

pes -= pes.min()
pes *= 1000

############################################################
# 2D interpolation
from scipy.interpolate import interp2d

N      = 100
x0     = np.linspace(0, 1, nx)
y0     = np.linspace(0, 1, ny)
x1     = np.linspace(0, 1, N)
y1     = np.linspace(0, 1, N)

fpes   = interp2d(x0, y0, pes, kind='cubic')
PES    = fpes(x1, y1)

# the 2D cell basis vectors
cell = [[ 3.1903160000000002,    0.0000000000000000],
        [-1.5951580000000001,    2.7628940000000002]]

cell = [[ 2.7628940000000002,    1.5951580000000001],
        [-2.7628940000000002,    1.5951580000000001]]

# the Cartesian coordinates of the shifting vectors
rx, ry = np.tensordot(cell, np.mgrid[0:1:1j*nx, 0:1:1j*ny], axes=(0, 0))
Rx, Ry = np.tensordot(cell, np.mgrid[0:1:1j*N, 0:1:1j*N], axes=(0, 0))

idx = range(N)
############################################################
fig = plt.figure(
    figsize=(4.8, 6.0),
    dpi=300
)
axes = [plt.subplot(211), plt.subplot(212)]

for ii in range(2):
    ax = axes[ii]

    if ii == 0:
        ax.set_aspect('equal')
        img = ax.pcolormesh(Rx, Ry, PES)

        ax.plot(Rx[idx, idx[::-1]], Ry[idx, idx[::-1]],
                ls='--', lw=1.0, color='b')
        ax.plot(Rx[idx, idx], Ry[idx, idx],
                ls='--', lw=1.0, color='r')

        divider = make_axes_locatable(ax)
        ax_cbar = divider.append_axes('right', size=0.15, pad=0.10)
        plt.colorbar(img, ax_cbar)

        ax_cbar.text(0.0, 1.05, 'meV', 
                     ha='left',
                     va='bottom',
                     transform=ax_cbar.transAxes)

        ax.set_xlabel(r'$x$ [$\AA$]', labelpad=5)
        ax.set_ylabel(r'$y$ [$\AA$]', labelpad=5)
    else:
        L1 = np.r_[
            [0],
            np.cumsum(
                np.linalg.norm(
                    np.diff(
                        np.array([Rx[idx, idx[::-1]], Ry[idx, idx[::-1]]]),
                        axis=1
                    ),
                    axis=0)
            )
        ]
        L2 = np.r_[
            [0],
            np.cumsum(
                np.linalg.norm(
                    np.diff(
                        np.array([Rx[idx, idx], Ry[idx, idx]]),
                        axis=1
                    ),
                    axis=0)
            )
        ]
        ax.plot(L1 - L1.max() / 2, PES[idx, idx[::-1]], color='b')
        ax.plot(L2 - L2.max() / 2, PES[idx, idx], color='r')

        ax.set_xlabel(r'Length [$\AA$]', labelpad=5)
        ax.set_ylabel(r'Energy [meV]', labelpad=5)


plt.tight_layout(pad=1)
plt.savefig('kaka.png')
plt.show()

